@@ -6,7 +6,6 @@
 */
 
 /*
-  ignore.h  -  description
   begin:     Mon Jun 24 2002
   copyright: (C) 2002 by Dario Abatianni
   email:     eisfuchs@tigress.com
@@ -35,10 +34,10 @@ class Ignore
       All=31
     };
 
-    Ignore(QString name,int flags);
+    Ignore(const QString &name,int flags);
     ~Ignore();
 
-    void setName(QString newName);
+    void setName(const QString &newName);
     void setFlags(int newFlags);
     QString getName();
     int getFlags();
