@@ -11,16 +11,26 @@ class KonsolePanel : public ChatWindow {
 	Q_OBJECT
 
 	public:
+#ifdef USE_MDI
+		KonsolePanel(const QString &caption);
+#else
 		KonsolePanel(QWidget *p);
+#endif
 		~KonsolePanel();
 
 	signals:
 		void deleted(ChatWindow* myself);
 
         public slots:
-		void adjustFocus();
 		void partDestroyed();
 
+#ifdef USE_MDI
+        protected:
+                virtual void closeYourself(ChatWindow*);
+#endif
+
+             	/** Called from ChatWindow adjustFocus */
+		virtual void childAdjustFocus();
 	private:
 		KParts::ReadOnlyPart *k_part;
 };
