@@ -6,7 +6,7 @@
 */
 
 /*
-  ledtab.h  -  The tabs with LEDs on them
+  The tabs with LEDs on them
   begin:     Fri Feb 22 2002
   copyright: (C) 2002 by Dario Abatianni
   email:     eisfuchs@tigress.com
@@ -20,8 +20,6 @@
 #include <qtabbar.h>
 #include <qtimer.h>
 
-#include "images.h"
-
 /*
   @author Dario Abatianni
 */
@@ -70,7 +68,6 @@ class LedTab : public QObject,public QTab
     bool online;    // if false label should be crossed out
 
     QWidget* widget;
-    Images images;
     QString labelColor;
 };
 
