@@ -6,7 +6,7 @@
 */
 
 /*
-  ledtabwidget.h  -  Extension of QTabWidget to support status LEDs
+  Extension of QTabWidget to support status LEDs
   begin:     Fri Feb 22 2002
   copyright: (C) 2002 by Dario Abatianni
   email:     eisfuchs@tigress.com
@@ -15,9 +15,7 @@
 #ifndef LEDTABWIDGET_H
 #define LEDTABWIDGET_H
 
-#include <qtabwidget.h>
-
-#include "images.h"
+#include <ktabwidget.h>
 
 /*
   @author Dario Abatianni
@@ -26,7 +24,7 @@
 class ChatWindow;
 class LedTabBar;
 
-class LedTabWidget : public QTabWidget
+class LedTabWidget : public KTabWidget
 {
   Q_OBJECT
 
@@ -43,24 +41,22 @@ class LedTabWidget : public QTabWidget
 
   public slots:
     void setTabOnline(ChatWindow* child,bool state);
-  
+
   protected slots:
     void moveTabLeft(int id);
     void moveTabRight(int id);
+    void moveTabToIndex(int oldIndex,int newIndex);
     void tabSelected(int id);
     void tabClosed(int id);
     void tabClosed();
     void changeName(ChatWindow* view,const QString& newName);
-    
+
 #ifndef QT_NO_WHEELEVENT
     void processWheelEvent(QWheelEvent *e);
 #endif
-    
-  protected:
-    void moveTabToIndex(int oldIndex,int newIndex);
-    LedTabBar* tabBar();
 
-    Images images;
+  protected:
+    LedTabBar* tabBar();
 
 #ifndef QT_NO_WHEELEVENT
     void wheelEvent(QWheelEvent *e);
