@@ -6,7 +6,7 @@
 */
 
 /*
-  prefspagealiases.h  -  The preferences GUI managing aliases
+  The preferences GUI managing aliases
   begin:     Mon Jul 14 2003
   copyright: (C) 2003 by Dario Abatianni
   email:     eisfuchs@tigress.com
@@ -15,20 +15,17 @@
 #ifndef PREFSPAGEALIASES_H
 #define PREFSPAGEALIASES_H
 
-#include <prefspage.h>
+#include "alias_preferences.h"
 
-/*
-  @author Dario Abatianni
-*/
+class Preferences;
+class QWidget;
 
-class KListView;
-
-class PrefsPageAliases : public PrefsPage
+class PrefsPageAliases : public Alias_Config
 {
   Q_OBJECT
 
   public:
-    PrefsPageAliases(QFrame* newParent,Preferences* newPreferences);
+    PrefsPageAliases(QWidget* newParent,Preferences* newPreferences);
     ~PrefsPageAliases();
 
   public slots:
@@ -39,7 +36,8 @@ class PrefsPageAliases : public PrefsPage
     void removeAlias();
 
   protected:
-    KListView* aliasesListView;
+    Preferences* preferences;
+    QWidget* parentFrame;
 
 };
 
