@@ -6,39 +6,33 @@
 */
 
 /*
-  prefspagebuttons.h  -  Provides an interface to edit the quick buttons
+  Provides an interface to edit the quick buttons
   begin:     Mon Jun 9 2003
   copyright: (C) 2003 by Dario Abatianni
   email:     eisfuchs@tigress.com
-
 */
 
 #ifndef PREFSPAGEBUTTONS_H
 #define PREFSPAGEBUTTONS_H
 
-#include "prefspage.h"
+#include "quickbuttons_preferences.h"
 
-/*
-  @author Dario Abatianni
-*/
+class Preferences;
 
-class KListView;
-
-class PrefsPageButtons : public PrefsPage
+class PrefsPageButtons : public QuickButtons_Config
 {
   Q_OBJECT
 
   public:
-    PrefsPageButtons(QFrame* newParent,Preferences* newPreferences);
+    PrefsPageButtons(QWidget* newParent,Preferences* newPreferences);
     ~PrefsPageButtons();
 
   public slots:
     void applyPreferences();
 
   protected:
+    Preferences* preferences;
     QStringList getButtonList();
-
-    KListView* buttonListView;
 };
 
 #endif
