@@ -6,7 +6,7 @@
 */
 
 /*
-  prefspagelog.h  -  Provides a user interface to customize logfile settings
+  Provides a user interface to customize logfile settings
   begin:     Son Okt 27 2002
   copyright: (C) 2002 by Dario Abatianni
   email:     eisfuchs@tigress.com
@@ -15,38 +15,25 @@
 #ifndef PREFSPAGELOG_H
 #define PREFSPAGELOG_H
 
-#include "prefspage.h"
+#include "log_preferences.h"
+class Preferences;
 
 /*
  *@author Dario Abatianni
 */
 
-class QCheckBox;
-class QLabel;
-class KLineEdit;
-class QSpinBox;
-class QGroupBox;
-
-class PrefsPageLog : public PrefsPage
+class PrefsPageLog : public Log_Config
 {
   Q_OBJECT
 
   public:
-    PrefsPageLog(QFrame* newParent,Preferences* newPreferences);
-    ~PrefsPageLog();
+    PrefsPageLog(QWidget* newParent,Preferences* newPreferences);
 
   public slots:
     void applyPreferences();
-
-  protected:
-
-    QGroupBox* loggingBox;
-    QCheckBox* lowerLog;
-    QCheckBox* logFollowsNick;
-    QLabel* logPathLabel;
-    KLineEdit* logPathInput;
-    QLabel* scrollbackMaxLabel;
-    QSpinBox* scrollbackMaxSpin;
+    
+protected:
+    Preferences* preferences;
 
 };
 
