@@ -6,7 +6,7 @@
 */
 
 /*
-  quickconnectdialog.h  -  Dialog for quick connection to an IRC network without adding a server in the Server List.
+  Dialog for quick connection to an IRC network without adding a server in the Server List.
   begin:     Sat June 05 2004
   copyright: (C) 2004 by Michael Goettsche
   email:     mail@tuxipuxi.de
@@ -33,9 +33,12 @@ class QuickConnectDialog : public KDialogBase
 		
 	signals:
 		void connectClicked(const QString& hostName, 
-						 const QString& port,
-						 const QString& nick,
-						 const QString& password);
+				    const QString& port,
+				    const QString& channel,
+				    const QString& nick,
+				    const QString& password,
+				    const bool& useSSL
+				    );
 				
 	protected slots:
 		void slotOk();
@@ -45,6 +48,7 @@ class QuickConnectDialog : public KDialogBase
 		KLineEdit*	portInput;
 		KLineEdit*	passwordInput;
 		KLineEdit*	nickInput;
+		QCheckBox*      sslCheckBox; 
 };
 
 #endif 
