@@ -16,11 +16,16 @@
 #include <kdebug.h>
 
 #include "rawlog.h"
+#include "channel.h"
 #include "ircview.h"
 #include "server.h"
 #include "konversationapplication.h"
 
+#ifdef USE_MDI
+RawLog::RawLog(QString caption) : ChatWindow(caption)
+#else
 RawLog::RawLog(QWidget* parent) : ChatWindow(parent)
+#endif
 {
   setName(i18n("Raw Log"));
   setType(ChatWindow::RawLog);
@@ -31,22 +36,46 @@ RawLog::~RawLog()
 {
 }
 
-void RawLog::adjustFocus()
+void RawLog::childAdjustFocus()
 {
-  // do nothing, just implement this to make abstract functions work
 }
 
 void RawLog::updateFonts()
 {
   getTextView()->setFont(KonversationApplication::preferences.getTextFont());
-  getTextView()->setViewBackground(KonversationApplication::preferences.getColor("TextViewBackground"),
-                                   KonversationApplication::preferences.getBackgroundImageName());
+
+  if(KonversationApplication::preferences.getShowBackgroundImage()) {
+    getTextView()->setViewBackground(KonversationApplication::preferences.getColor("TextViewBackground"),
+                                  KonversationApplication::preferences.getBackgroundImageName());
+  } else {
+    getTextView()->setViewBackground(KonversationApplication::preferences.getColor("TextViewBackground"),
+      QString::null);
+  }
 }
 
-void RawLog::closeYourself()
+bool RawLog::closeYourself()
+{
+#ifndef USE_MDI
+  // make the server delete us so server can reset the pointer to us
+  m_server->closeRawLog();
+#endif
+  return true;
+}
+
+#ifdef USE_MDI
+void RawLog::closeYourself(ChatWindow*)
 {
   // make the server delete us so server can reset the pointer to us
-  server->closeRawLog();
+  m_server->closeRawLog();
+  emit chatWindowCloseRequest(this);
+}
+#endif
+
+void RawLog::serverQuit(const QString&)
+{
+#ifdef USE_MDI
+  closeYourself(this);
+#endif
 }
 
 bool RawLog::searchView() { return true; }
